@@ -156,8 +156,14 @@ get_context (xmlNodePtr elem, TokenContext * ctx)
   ctx->id = (gchar *) xmlGetProp (elem, (xmlChar *) "id");
 
   if (!ctx->id) {
-    g_assert (elem->parent);
-    get_context (elem->parent, ctx);
+    xmlNodePtr prev_sibling = xmlPreviousElementSibling (elem);
+
+    if (prev_sibling) {
+      get_context (prev_sibling, ctx);
+    } else {
+      g_assert (elem->parent);
+      get_context (elem->parent, ctx);
+    }
   }
 }
 
@@ -204,7 +210,8 @@ parse_tokens (IndexContext *idx_ctx, TokenContext *ctx, const gchar *url, gchar
   while (str[i] &&
       ((str[i] >= 'a' && str[i] <= 'z') ||
           (str[i] >= 'A' && str[i] <= 'Z') ||
-          (str[i] >= '0' && str[i] <= '9') || str[i] == '_' || str[i] == '.')) {
+          (str[i] >= '0' && str[i] <= '9') ||
+          str[i] == '_' || str[i] == '.' || str[i] == '-')) {
     i++;
   }
 
